Food.com - Thousands Of Free Recipes From Home Chefs With Recipe Ratings, Reviews And Tips
Description: Food.com has a massive collection of recipes that are submitted, rated and reviewed by people who are passionate about food. From international cuisines to quick and easy meal ideas, Food.com is where you can find what youre craving.
Keywords: recipe recipes food meal ideas menus chef recipies

Log In Sign Up

- Recipe Box
- Grocery List
- My Profile
- My Inbox
- Account Settings
- Log Out

Add a Recipe
Looking for your public and private recipes or recipes with notes? They're now in your new Recipe Box.

Learn More

## Recipe Sifter

X

- ###### Start Here

  - Course
  - Main Ingredient
  - Cuisine
  - Preparation
  - Occasion
  - Diet
  - Filter by Ingredient
  - Nutrition

1

Select () or exclude () categories to narrow your recipe search.

2

As you select categories, the number of matching recipes will update.

##### Make some selections to begin narrowing your results.

Get Recipes
- Calories
- Amount per serving
  1. Total Fat
  2. Saturated Fat
  3. Polyunsat. Fat
  4. Monounsat. Fat
  5. Trans Fat
- Cholesterol
- Sodium
- Potassium
- Total Carbohydrates
  1. Dietary Fiber
  2. Sugars
- Protein
- Vitamin A
- Vitamin B6
- Vitamin B12
- Vitamin C
- Calcium
- Iron
- Vitamin E
- Magnesium
- Alcohol
- Caffeine

Find exactly what you're looking for with the web's most powerful recipe filtering tool.

## Popular Categories

- Christmas Recipes
- Slow Cooker Recipes
- Chicken Recipes
- Main Dish Recipes
- Appetizer Recipes
- Pressure Cooker Recipes
- Popular Winter Recipes
- 5-Ingredient Dessert Recipes
- Side Dish Recipes
- Ground Beef Recipes

Browse All Recipes

## Top Ten Searches

1. Weight Watchers Recipes
2. Finger Food Recipes
3. Tater Tot Casserole Recipes
4. Popular Cod Recipes
5. Slow-Cooker Soup Recipes
6. Bread Machine Recipes
7. Steak Recipes
8. Fried Rice Recipes
9. Cabbage Soup Recipes

## Top Recipes

- Macaroni & Cheese
- Oven BBQ Ribs
- Copycat Zuppa Toscana
- Alfredo Sauce Recipe
- Chinese Fried Rice
- Bourbon Chicken Recipe
- Our #1 Meatloaf Recipe
- Spinach-Artichoke Dip Recipe
- Beef & Broccoli Stir-Fry
- Best Oatmeal Cookies

Photo by run for your life

### 50+ DIY Food Gifts

Truffles, fudge, salted caramel — we've got the homemade goodies you want to give.

Give ‘em what they really want »

### Ready, Set, Ho Ho Ho

And here we are — the gravy’s not even cold and the holidays are upon us. Get merry with our best bets.

- 32 Essential Christmas Cookies
- Super-Quick Shortcut Appetizers
- Top Cakes, Cupcakes, Puddings & Pies

Fa la la’ing starts now »

### Your Holiday Survival Kit

We've rounded up our home cooks' best recipes and advice so you can sail through December with ease.

How does she do it? »

##### Recipe of the Day

Caramel Filled DelightFulls™ Chocolate Chip Cookies

By Toll House®
Photo by Toll House®

0 Reviews
Sponsored by:

### Chef of the Day

SarahEmmm

#### About SarahEmmm:

> The first 'real cooking' I remember doing was oeufs mollets aux fines herbes when I was eight.

#### SarahEmmm's Top Recipes

- Butternut Squash Soup
- Cabbage with Caraway
- Jane's Amazing Lunchbox Salad

SarahEmmm's recipes »

Become a chef »

### Festive Finger Foods

- 1-3 of 9

  - Roasted Garlic Crostini

  - Super-Quick Cheese Puffs

  - Coconut Chicken with Apricot Chutney

- 4-6 of 9

  - Hummus-Filled Cucumber Logs

  - Tomato Devils

  - Bacon Deviled Eggs

- 7-9 of 9

  - Tater-Tot Potato Skins

  - Cranberry & Sausage Tartlets

  - Mushroom Puffs

### Check It Out

#### The New App Is Here!

Get recipe inspiration, save on groceries and put dinner on the table stress-free.

- Get all the details
- Watch what it can do live
- Download it now

Find Recipes. Plan Meals. Score Deals. »

##### Top Picks

Sesame Chicken

Baked Ziti

Slow-Cooker Pork Roast

Parmesan Fish

Chinese Fried Rice

### Weeknight Dinner Winners

See all our quick & easy ideas »

- 1-3 of 9

  - Pork Cutlet Parmesan

  - Mushroom & Bacon Pasta

  - California Chicken

- 4-6 of 9

  - Salmon Patties with Seasoned Mayo

  - Spicy Skillet Pork Chops

  - Easy Fried Rice

- 7-9 of 9

  - Simple Risotto

  - Chicken Satay

  - Pesto & Cheese Melts

### Popular Recipes

Enjoy the season to the fullest with our home cooks' favorite recipes.

#### Cookie & Brownie Recipes

- I Want To Marry You Cookies
- Microwave Chocolate Mug Brownie
- No-Bake Chocolate Oatmeal Cookies

#### Chicken Recipes

- Caramelized Baked Chicken Wings
- P.F. Chang's Chicken Lettuce Wraps
- Simple Baked Chicken Drumsticks

#### Potato Side Dish Recipes

- Scalloped Potatoes
- Funeral Potatoes
- Cracker Barrel's Hash Browns Casserole

#### Easy Christmas Dessert Recipes

- Cut-Out Sugar Cookies with Icing
- Oreo Balls
- Wonderful Gingerbread Cookies

#### Pork Recipes

- Pork Tenderloin With Gravy
- Pork Chops Yum-Yum
- Perfect Pork Tenderloin

#### Slow-Cooker Recipes

- To-Die-For Crock-Pot Roast
- Whole Chicken Crock-Pot Recipe
- Slow-Cooker Pulled Pork

#### Pasta Recipes

- Baked Ziti Recipe
- Absolute Best Ever Lasagna
- Creamy Cajun Chicken Pasta

#### Mexican Recipes

- Mexican Rice
- Authentic Guacamole
- Sour Cream Chicken Enchiladas

#### Vegetable Recipes

- Butternut Squash Recipes
- Corn Pudding
- Broccoli Casserole

#### Soup Recipes

- Chicken Noodle Soup
- Egg Drop Soup
- Chicken & Dumplings

From Our Food.com Family

Celebrate the holidays with our favorite cookies from Ree, Alton, Ina and more.

From Our Food.com Family

See Jonathan & Drew Scott create their ultimate Las Vegas getaway.

Advertisement

### Just Added

Recipe

Crock Pot Turkey White Bean Pumpkin Chili

By Sica
Photo

Ground Beef Supreme Yumminess

By stonecoldcrazy
Review

#### Jo Mama's World Famous Spaghetti

My kids will give up a steak dinner for this spaghetti. It is...

By Sharlene~W
New Chef

Chef #1803455240

Recipe

Mom's Banana Bread

By Rebecca Becker
Photo

My Mom's Apple Cake

By Ciocia DD
Review

#### Asian Barbecue Sauce

I've found Sriracha Chili Sauce with Garlic a couple of times...

By breezermom
New Chef

tammyanderson1245

Recipe

Mozzarella Bruchetta

By Chef #1803186270
Photo

Baked Ricotta With Lemon, Garlic, & Chives

By twissis
Review

#### Roasted Chicken With Lemon Cream Sauce

I love the smell of chicken roasting in the oven. It makes me...

By breezermom
New Chef

Chef #1803455232

Recipe

Best Chicken Stew (America's Test Kitchen)

By Twiggyann
Photo

Diabetic Spring Fling Layered White Cake

By May I Have That Recipe
Review

#### The Best Bowl of Chili I've Ever Had...

I actually took 5 chili recipes and took out all the things I...

By Dee Licious
New Chef

Chef #1803455230

Recipe

Mexicali Bake

By Chef Readi
Photo

World-Famous Low Carb Bread

By May I Have That Recipe
Review

#### Acorn Squash With Butter Pecan Sauce

Incredibly simple and delightfully good!

By Annacia
New Chef

Chef #1803455229

#### The Newest ...

- 15 Recipes
- 23 Photos

- 73 Reviews
- 1347 Users

### Free Weekly Newsletter

Get the latest recipes and tips delivered right to your inbox.

Your e-mail is safe. Privacy Policy

### Everyday Meal Ideas

Ground Beef Dinners

Get a great meal on the table that the whole family will love with these time-saving picks.

- Rush Hour Recipes
- Easy Entertaining Ideas

Find more popular picks

Advertisement

#### Over 475,000 Recipes

- All Recipes
- All Categories
- Get a Random Recipe
- Kitchen Dictionary
- Measurement Converter

#### Food.com Network of Sites

- Mexican Recipes
- Chinese Recipes
- Australian Recipes
- Breakfast Recipes
- Greek Recipes
- Restaurant Recipes
- Italian Recipes
- Christmas Recipes
- Thanksgiving Recipes
- Southern Recipes
- Dessert Recipes
- Deep Fried Recipes
- Thai Recipes
- Low Cholesterol Recipes
- Indian Recipes
- Healthy Recipes
- Meatloaf Recipes